/**
 * PETALS - PETALS Services Platform.
 * Copyright (c) 2005-2006 EBM WebSourcing, http://www.ebmwebsourcing.com/
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or (at your option) any later version.
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 *
 * -------------------------------------------------------------------------
 * $Id: Fault.java,v 1.1 2007/06/11 13:34:07 lam Exp $
 * -------------------------------------------------------------------------
 */
package org.objectweb.petals.tools.rmi.common.serializable;

import java.io.ByteArrayInputStream;
import java.io.UnsupportedEncodingException;

import javax.jbi.messaging.MessagingException;
import javax.xml.transform.stream.StreamSource;


/**
 *
 * @author nsalatge
 *
 */
public class Fault extends NormalizedMessage implements javax.jbi.messaging.Fault {

    /**
     * the serialVersionUID.
     */
    private static final long serialVersionUID = 1L;

    /**
     * Error message.
     */
    private static final String ERROR_MSG = "Impossible to create a fault";

    /**
     * Format.
     */
    private static final String FORMAT = "UTF-8";

    /**
     * the default constructor.
     * @param msg
     *        the fault message
     * @throws MessagingException
     *        impossible to create a fault
     */
    public Fault(final String msg) throws MessagingException  {
        StreamSource source = new StreamSource();

        byte[] msgByte;
        try {
            String fault = "<text>Fault: " + msg + "</text>";
            msgByte = fault.getBytes(Fault.FORMAT);
            ByteArrayInputStream in = new ByteArrayInputStream(msgByte);
            source.setInputStream(in);
        } catch (UnsupportedEncodingException e) {
            throw new MessagingException(Fault.ERROR_MSG);
        }

        this.setContent(source);
    }

    /**
     * the default constructor.
     * @throws MessagingException
     *          impossible to create a fault
     */
    public Fault() throws MessagingException  {
        StreamSource source = new StreamSource();

        byte[] msgByte;
        try {
            String fault = "<text>Fault</text>";
            msgByte = fault.getBytes(Fault.FORMAT);
            ByteArrayInputStream in = new ByteArrayInputStream(msgByte);
            source.setInputStream(in);
        } catch (UnsupportedEncodingException e) {
            throw new MessagingException(Fault.ERROR_MSG);
        }

        this.setContent(source);
    }
}
