/**
 * PETALS - PETALS Services Platform.
 * Copyright (c) 2005-2006 EBM WebSourcing, http://www.ebmwebsourcing.com/
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or (at your option) any later version.
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 *
 * -------------------------------------------------------------------------
 * $Id: ServiceEndpoint.java,v 1.1 2007/06/11 13:34:07 lam Exp $
 * -------------------------------------------------------------------------
 */
package org.objectweb.petals.tools.rmi.common.serializable;

import java.io.Serializable;

import javax.xml.namespace.QName;

/**
 * RMI implementation of service endpoint.
 * @author nsalatge
 *
 */
public class ServiceEndpoint
implements javax.jbi.servicedesc.ServiceEndpoint, Serializable {

    /**
     * default serialVersionUID.
     */
    private static final long serialVersionUID = 1L;

    /**
     * the endpoint name.
     */
    private String endpointName = null;

    /**
     * the interfaces.
     */
    private QName[] interfaces = null;

    /**
     * the service name.
     */
    private QName serviceName = null;


    /**
     * the default constructor.
     * @param serviceName
     *          the service name
     * @param endpointName
     *          the endpoint name
     * @param interfaces
     *          the interfaces
     */
    public ServiceEndpoint(final QName serviceName,
            final String endpointName, final QName[] interfaces) {
        this.endpointName = endpointName;
        this.interfaces = interfaces;
        this.serviceName = serviceName;
    }

    /**
     * Get the endpoint name.
     * @return
     *       the endpoint name
     */
    public String getEndpointName() {
        return this.endpointName;
    }

    /**
     * Get interfaces.
     * @return
     *       the interfaces.
     */
    public QName[] getInterfaces() {
        return this.interfaces;
    }

    /**
     * Get service names.
     * @return
     *     the service name
     */
    public QName getServiceName() {
        return this.serviceName;
    }

    /**
     * Get the reference.
     * @param operationName
     *        the operation name
     * @return
     *     the document fragment
     */
    public org.w3c.dom.DocumentFragment getAsReference(final
            javax.xml.namespace.QName operationName) {
        throw new NoSuchMethodError("Not implemented.");
    }

    /** toString method.
     * @return the string representation of service endpoint
     */
    public String toString() {
        String res = "";
        res = res + "serviceName = " + this.serviceName;
        res = res + "endpointName = " + this.endpointName;
        res = res + "interfaces = " + this.interfaces;
        return res;
    }
}
